@@ -25,8 +25,12 @@ bool is_altrep(SEXP x);
 
 SEXP ffi_extract_altrep_class(SEXP x);
 
+SEXP ffi_is_sparse_vector(SEXP x);
+
 R_xlen_t binary_search(int needle, const int* v_haystack, R_xlen_t size);
 
 bool is_index_handleable(SEXP x);
 
+void verbose_materialize(void);
+
 #endif
